@@ -8,7 +8,7 @@
 #          Ricardo Garcia Silva <ricardo.garcia.silva@geobeyond.it>
 #
 # Copyright (c) 2025 Tom Kralidis
-# Copyright (c) 2022 Francesco Bartoli
+# Copyright (c) 2025 Francesco Bartoli
 # Copyright (c) 2022 John A Stevenson and Colin Blackburn
 # Copyright (c) 2023 Ricardo Garcia Silva
 #
@@ -66,7 +66,8 @@ from pygeoapi.util import (
     CrsTransformSpec, TEMPLATES, UrlPrefetcher, dategetter,
     filter_dict_by_key_value, filter_providers_by_type, get_api_rules,
     get_base_url, get_provider_by_type, get_provider_default, get_typed_value,
-    get_crs_from_uri, get_supported_crs_list, render_j2_template, to_json
+    get_crs_from_uri, get_supported_crs_list, render_j2_template, to_json,
+    get_choice_from_headers, get_from_headers
 )
 
 LOGGER = logging.getLogger(__name__)
@@ -150,7 +151,8 @@ def apply_gzip(headers: dict, content: Union[str, bytes]) -> Union[str, bytes]:
     Compress content if requested in header.
     """
     charset = CHARSET[0]
-    if F_GZIP in headers.get('Content-Encoding', []):
+
+    if F_GZIP in get_from_headers(headers, 'content-encoding'):
         try:
             if isinstance(content, bytes):
                 # bytes means Content-Type needs to be set upstream
@@ -212,6 +214,7 @@ class APIRequest:
     :param request:             The web platform specific Request instance.
     :param supported_locales:   List or set of supported Locale instances.
     """
+
     def __init__(self, request, supported_locales):
         # Set default request data
         self._data = b''
@@ -305,16 +308,18 @@ class APIRequest:
             raise ValueError(f"{self.__class__.__name__} must be initialized"
                              f"with a list of valid supported locales")
 
-        for func, mapping in ((l10n.locale_from_params, self._args),
-                              (l10n.locale_from_headers, headers)):
-            loc_str = func(mapping)
-            if loc_str:
-                if not raw:
+        for field, mapping in ((l10n.QUERY_PARAM, self._args),
+                               ('accept-language', headers)):
+
+            loc_strs = get_choice_from_headers(mapping, field, all=True)
+            if loc_strs:
+                if raw is None:
                     # This is the first-found locale string: set as raw
-                    raw = loc_str
+                    raw = get_from_headers(mapping, field)
+
                 # Check if locale string is a good match for the UI
-                loc = l10n.best_match(loc_str, supported_locales)
-                is_override = func is l10n.locale_from_params
+                loc = l10n.best_match(loc_strs, supported_locales)
+                is_override = field is l10n.QUERY_PARAM
                 if loc != default_locale or is_override:
                     return raw, loc
 
@@ -335,17 +340,16 @@ class APIRequest:
             return format_
 
         # Format not specified: get from Accept headers (MIME types)
-        # e.g. format_ = 'text/html'
-        h = headers.get('accept', headers.get('Accept', '')).strip() # noqa
+        # e.g. Accept: 'text/html;q=0.5,application/ld+json'
+        types_ = get_choice_from_headers(headers, 'accept', all=True)
+        if types_ is None:
+            return
+
         (fmts, mimes) = zip(*FORMAT_TYPES.items())
-        # basic support for complex types (i.e. with "q=0.x")
-        for type_ in (t.split(';')[0].strip() for t in h.split(',') if t):
+        for type_ in types_:
             if type_ in mimes:
                 idx_ = mimes.index(type_)
-                format_ = fmts[idx_]
-                break
-
-        return format_ or None
+                return fmts[idx_]
 
     @property
     def data(self) -> bytes:
@@ -503,7 +507,7 @@ class APIRequest:
         if F_GZIP in FORMAT_TYPES:
             if force_encoding:
                 headers['Content-Encoding'] = force_encoding
-            elif F_GZIP in self._headers.get('Accept-Encoding', ''):
+            elif F_GZIP in get_from_headers(self._headers, 'accept-encoding'):
                 headers['Content-Encoding'] = F_GZIP
 
         return headers
@@ -656,7 +660,7 @@ class API:
 
         if not query_crs_uri:
             if storage_crs_uri in DEFAULT_CRS_LIST:
-                # Could be that storageCRS is
+                # Could be that storageCrs is
                 # http://www.opengis.net/def/crs/OGC/1.3/CRS84h
                 query_crs_uri = storage_crs_uri
             else:
@@ -713,7 +717,7 @@ class API:
             # If empty use default CRS
             storage_crs_uri = config.get('storage_crs', DEFAULT_STORAGE_CRS)
             if storage_crs_uri in DEFAULT_CRS_LIST:
-                # Could be that storageCRS is one of the defaults like
+                # Could be that storageCrs is one of the defaults like
                 # http://www.opengis.net/def/crs/OGC/1.3/CRS84h
                 content_crs_uri = storage_crs_uri
             else:
@@ -1134,10 +1138,10 @@ def describe_collections(api: API, request: APIRequest,
 
         # OAPIF Part 2 - list supported CRSs and StorageCRS
         if collection_data_type in ['edr', 'feature']:
-            collection['crs'] = get_supported_crs_list(collection_data, DEFAULT_CRS_LIST) # noqa
-            collection['storageCRS'] = collection_data.get('storage_crs', DEFAULT_STORAGE_CRS) # noqa
+            collection['crs'] = get_supported_crs_list(collection_data, DEFAULT_CRS_LIST)  # noqa
+            collection['storageCrs'] = collection_data.get('storage_crs', DEFAULT_STORAGE_CRS)  # noqa
             if 'storage_crs_coordinate_epoch' in collection_data:
-                collection['storageCrsCoordinateEpoch'] = collection_data.get('storage_crs_coordinate_epoch') # noqa
+                collection['storageCrsCoordinateEpoch'] = collection_data.get('storage_crs_coordinate_epoch')  # noqa
 
         elif collection_data_type == 'coverage':
             # TODO: translate
@@ -1176,7 +1180,7 @@ def describe_collections(api: API, request: APIRequest,
                     collection['extent']['spatial']['grid'] = [{
                         'cellsCount': p._coverage_properties['width'],
                         'resolution': p._coverage_properties['resx']
-                        }, {
+                    }, {
                         'cellsCount': p._coverage_properties['height'],
                         'resolution': p._coverage_properties['resy']
                     }]
@@ -1424,6 +1428,8 @@ def get_collection_schema(api: API, request: Union[APIRequest, Any],
 
     for k, v in p.fields.items():
         schema['properties'][k] = v
+        if v['type'] == 'float':
+            schema['properties'][k]['type'] = 'number'
         if v.get('format') is None:
             schema['properties'][k].pop('format', None)
 
@@ -1664,7 +1670,7 @@ def evaluate_limit(requested: Union[None, int], server_limits: dict,
     if requested2 <= 0:
         raise ValueError('limit value should be strictly positive')
     elif requested2 > max_ and on_exceed == 'error':
-        raise RuntimeError('Limit exceeded; throwing errror')
+        raise ValueError(f'Limit of {max_} exceeded')
     else:
         LOGGER.debug('limit requested')
         return min(requested2, max_)
