@@ -7,8 +7,8 @@
 #          Colin Blackburn <colb@bgs.ac.uk>
 #          Ricardo Garcia Silva <ricardo.garcia.silva@geobeyond.it>
 #
-# Copyright (c) 2024 Tom Kralidis
-# Copyright (c) 2022 Francesco Bartoli
+# Copyright (c) 2025 Tom Kralidis
+# Copyright (c) 2025 Francesco Bartoli
 # Copyright (c) 2022 John A Stevenson and Colin Blackburn
 # Copyright (c) 2023 Ricardo Garcia Silva
 #
@@ -35,7 +35,7 @@
 #
 # =================================================================
 
-
+from collections import ChainMap
 from copy import deepcopy
 from datetime import datetime
 from http import HTTPStatus
@@ -111,6 +111,7 @@ def get_collection_queryables(api: API, request: Union[APIRequest, Any],
     :returns: tuple of headers, status code, content
     """
 
+    domains = {}
     headers = request.get_response_headers(**api.api_headers)
 
     if any([dataset is None,
@@ -135,16 +136,39 @@ def get_collection_queryables(api: API, request: Union[APIRequest, Any],
     if p is None:
         msg = 'queryables not available for this collection'
         return api.get_exception(
+
             HTTPStatus.BAD_REQUEST, headers, request.format,
             'NoApplicableError', msg)
 
+    LOGGER.debug('Processing profile')
+    profile = request.params.get('profile', '')
+
+    LOGGER.debug('Processing properties')
+    val = request.params.get('properties')
+    if val is not None:
+        properties = [x for x in val.split(',') if x]
+        properties_to_check = set(p.properties) | set(p.fields.keys())
+
+        if len(list(set(properties) - set(properties_to_check))) > 0:
+            msg = 'unknown properties specified'
+            return api.get_exception(
+                HTTPStatus.BAD_REQUEST, headers, request.format,
+                'InvalidParameterValue', msg)
+    else:
+        properties = []
+
+    queryables_id = f'{api.get_collections_url()}/{dataset}/queryables'
+
+    if request.params:
+        queryables_id += '?' + urllib.parse.urlencode(request.params)
+
     queryables = {
         'type': 'object',
         'title': l10n.translate(
             api.config['resources'][dataset]['title'], request.locale),
         'properties': {},
         '$schema': 'http://json-schema.org/draft/2019-09/schema',
-        '$id': f'{api.get_collections_url()}/{dataset}/queryables'
+        '$id': queryables_id
     }
 
     if p.fields:
@@ -153,8 +177,17 @@ def get_collection_queryables(api: API, request: Union[APIRequest, Any],
             'x-ogc-role': 'primary-geometry'
         }
 
+    if profile == 'actual-domain':
+        try:
+            domains, _ = p.get_domains(properties)
+        except NotImplementedError:
+            LOGGER.debug('Domains are not suported by this provider')
+            domains = {}
+
     for k, v in p.fields.items():
         show_field = False
+        if properties and k not in properties:
+            continue
         if p.properties:
             if k in p.properties:
                 show_field = True
@@ -166,6 +199,8 @@ def get_collection_queryables(api: API, request: Union[APIRequest, Any],
                 'title': k,
                 'type': v['type']
             }
+            if v['type'] == 'float':
+                queryables['properties'][k]['type'] = 'number'
             if v.get('format') is not None:
                 queryables['properties'][k]['format'] = v['format']
             if 'values' in v:
@@ -175,6 +210,8 @@ def get_collection_queryables(api: API, request: Union[APIRequest, Any],
                 queryables['properties'][k]['x-ogc-role'] = 'id'
             if k == p.time_field:
                 queryables['properties'][k]['x-ogc-role'] = 'primary-instant'  # noqa
+            if domains.get(k):
+                queryables['properties'][k]['enum'] = domains[k]
 
     if request.format == F_HTML:  # render
         tpl_config = api.get_dataset_templates(dataset)
@@ -352,7 +389,7 @@ def get_collection_items(
                 HTTPStatus.BAD_REQUEST, headers, request.format,
                 'NoApplicableCode', msg)
 
-        supported_crs_list = get_supported_crs_list(provider_def, DEFAULT_CRS_LIST) # noqa
+        supported_crs_list = get_supported_crs_list(provider_def, DEFAULT_CRS_LIST)  # noqa
         if bbox_crs not in supported_crs_list:
             msg = f'bbox-crs {bbox_crs} not supported for this collection'
             return api.get_exception(
@@ -362,12 +399,12 @@ def get_collection_items(
         # bbox but no bbox-crs param: assume bbox is in default CRS
         bbox_crs = DEFAULT_CRS
 
-    # Transform bbox to storageCRS
-    # when bbox-crs different from storageCRS.
+    # Transform bbox to storageCrs
+    # when bbox-crs different from storageCrs.
     if len(bbox) > 0:
         try:
             # Get a pyproj CRS instance for the Collection's Storage CRS
-            storage_crs = provider_def.get('storage_crs', DEFAULT_STORAGE_CRS) # noqa
+            storage_crs = provider_def.get('storage_crs', DEFAULT_STORAGE_CRS)  # noqa
 
             # Do the (optional) Transform to the Storage CRS
             bbox = transform_bbox(bbox, bbox_crs, storage_crs)
@@ -378,13 +415,16 @@ def get_collection_items(
 
     LOGGER.debug('processing property parameters')
     for k, v in request.params.items():
+        include_query_param = False
         if k not in reserved_fieldnames:
-            if k in list(p.fields.keys()):
-                LOGGER.debug(f'Adding property filter {k}={v}')
-            else:
-                LOGGER.debug(f'Adding additional property filter {k}={v}')
+            if k in list(p.fields.keys()) or p.include_extra_query_parameters:
+                include_query_param = True
 
+        if include_query_param:
+            LOGGER.debug(f'Including query parameter {k}={v}')
             properties.append((k, v))
+        else:
+            LOGGER.debug(f'Discarding query parameter {k}={v}')
 
     LOGGER.debug('processing sort parameter')
     val = request.params.get('sortby')
@@ -545,7 +585,21 @@ def get_collection_items(
         'href': f'{uri}?f={F_HTML}{serialized_query_params}'
     }])
 
-    if offset > 0:
+    next_link = False
+    prev_link = False
+
+    if 'next' in [link['rel'] for link in content['links']]:
+        LOGGER.debug('Using next link from provider')
+    else:
+        if content.get('numberMatched', -1) > (limit + offset):
+            next_link = True
+        elif len(content['features']) == limit:
+            next_link = True
+
+        if offset > 0:
+            prev_link = True
+
+    if prev_link:
         prev = max(0, offset - limit)
         content['links'].append(
             {
@@ -555,13 +609,6 @@ def get_collection_items(
                 'href': f'{uri}?offset={prev}{serialized_query_params}'
             })
 
-    next_link = False
-
-    if content.get('numberMatched', -1) > (limit + offset):
-        next_link = True
-    elif len(content['features']) == limit:
-        next_link = True
-
     if next_link:
         next_ = offset + limit
         next_href = f'{uri}?offset={next_}{serialized_query_params}'
@@ -621,8 +668,8 @@ def get_collection_items(
                 data=content,
                 options={
                     'provider_def': get_provider_by_type(
-                                        collections[dataset]['providers'],
-                                        'feature')
+                        collections[dataset]['providers'],
+                        'feature')
                 }
             )
         except FormatterSerializationError:
@@ -964,7 +1011,7 @@ def create_crs_transform_spec(
 
     if not query_crs_uri:
         if storage_crs_uri in DEFAULT_CRS_LIST:
-            # Could be that storageCRS is
+            # Could be that storageCrs is
             # http://www.opengis.net/def/crs/OGC/1.3/CRS84h
             query_crs_uri = storage_crs_uri
         else:
@@ -1021,7 +1068,7 @@ def set_content_crs_header(
         # If empty use default CRS
         storage_crs_uri = config.get('storage_crs', DEFAULT_STORAGE_CRS)
         if storage_crs_uri in DEFAULT_CRS_LIST:
-            # Could be that storageCRS is one of the defaults like
+            # Could be that storageCrs is one of the defaults like
             # http://www.opengis.net/def/crs/OGC/1.3/CRS84h
             content_crs_uri = storage_crs_uri
         else:
@@ -1057,6 +1104,34 @@ def get_oas_30(cfg: dict, locale: str) -> tuple[list[dict[str, str]], dict[str,
         }
     }
 
+    limit = {
+        'name': 'limit',
+        'in': 'query',
+        'description': 'The optional limit parameter limits the number of items that are presented in the response document',  # noqa
+        'required': False,
+        'schema': {
+            'type': 'integer',
+            'minimum': 1,
+            'maximum': 10000,
+            'default': 100
+        },
+        'style': 'form',
+        'explode': False
+    }
+
+    profile = {
+        'name': 'profile',
+        'in': 'query',
+        'description': 'The profile to be applied to a given request',
+        'required': False,
+        'style': 'form',
+        'explode': False,
+        'schema': {
+            'type': 'string',
+            'enum': ['actual-domain', 'valid-domain']
+        }
+    }
+
     LOGGER.debug('setting up collection endpoints')
     paths = {}
 
@@ -1087,6 +1162,11 @@ def get_oas_30(cfg: dict, locale: str) -> tuple[list[dict[str, str]], dict[str,
 
             coll_properties['schema']['items']['enum'] = list(p.fields.keys())
 
+            coll_limit = _derive_limit(
+                deepcopy(limit), cfg['server'].get('limits', {}),
+                v.get('limits', {})
+            )
+
             paths[items_path] = {
                 'get': {
                     'summary': f'Get {title} items',
@@ -1097,7 +1177,7 @@ def get_oas_30(cfg: dict, locale: str) -> tuple[list[dict[str, str]], dict[str,
                         {'$ref': '#/components/parameters/f'},
                         {'$ref': '#/components/parameters/lang'},
                         {'$ref': '#/components/parameters/bbox'},
-                        {'$ref': f"{OPENAPI_YAML['oapif-1']}#/components/parameters/limit"},  # noqa
+                        coll_limit,
                         {'$ref': '#/components/parameters/crs'},  # noqa
                         {'$ref': '#/components/parameters/bbox-crs'},
                         coll_properties,
@@ -1190,7 +1270,9 @@ def get_oas_30(cfg: dict, locale: str) -> tuple[list[dict[str, str]], dict[str,
                         'tags': [k],
                         'operationId': f'get{k.capitalize()}Queryables',
                         'parameters': [
+                            coll_properties,
                             {'$ref': '#/components/parameters/f'},
+                            profile,
                             {'$ref': '#/components/parameters/lang'}
                         ],
                         'responses': {
@@ -1346,3 +1428,28 @@ def get_oas_30(cfg: dict, locale: str) -> tuple[list[dict[str, str]], dict[str,
             LOGGER.debug('collection is not feature/item based')
 
     return [{'name': 'records'}, {'name': 'features'}], {'paths': paths}
+
+
+def _derive_limit(limit_object, server_limits, collection_limits) -> dict:
+    """
+    Helper function to derive a limit object for a given collection
+
+    :param limit_object: OpenAPI limit parameter
+    :param server_limits: server level limits configuration
+    :param collection_limits: collection level limits configuration
+
+    :returns: updated limit object
+    """
+
+    effective_limits = ChainMap(collection_limits, server_limits)
+
+    default_limit = effective_limits.get('default_items', 10)
+    max_limit = effective_limits.get('max_items', 10)
+
+    limit_object['schema']['default'] = default_limit
+    limit_object['schema']['maximum'] = max_limit
+
+    text = f' (maximum={max_limit}, default={default_limit}).'
+    limit_object['description'] += text
+
+    return limit_object
