@@ -5,7 +5,7 @@
 # Authors: Ricardo Garcia Silva <ricardo.garcia.silva@geobeyond.it>
 #
 # Copyright (c) 2024 Tom Kralidis
-# Copyright (c) 2022 Francesco Bartoli
+# Copyright (c) 2025 Francesco Bartoli
 # Copyright (c) 2023 Ricardo Garcia Silva
 #
 # Permission is hereby granted, free of charge, to any person
@@ -410,9 +410,7 @@ def get_oas_30(cfg: dict, fail_on_invalid_collection: bool = True) -> dict:
                     'language': {
                         'description': 'the language used for the title and description', # noqa
                         'type': 'string',
-                        'default': [
-                            'en'
-                        ]
+                        'default': 'en'
                     },
                     'type': {
                         'description': 'the data type of the queryable', # noqa
