@@ -2,7 +2,7 @@
 #
 # Authors: Tom Kralidis <tomkralidis@gmail.com>
 #
-# Copyright (c) 2022 Tom Kralidis
+# Copyright (c) 2025 Tom Kralidis
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -30,6 +30,9 @@
 import json
 import logging
 from enum import Enum
+from http import HTTPStatus
+
+from pygeoapi.error import GenericError
 
 LOGGER = logging.getLogger(__name__)
 
@@ -66,11 +69,13 @@ class BaseProvider:
         self.uri_field = provider_def.get('uri_field')
         self.x_field = provider_def.get('x_field')
         self.y_field = provider_def.get('y_field')
+        self.z_field = provider_def.get('z_field')
         self.time_field = provider_def.get('time_field')
         self.title_field = provider_def.get('title_field')
         self.properties = provider_def.get('properties', [])
         self.file_types = provider_def.get('file_types', [])
-        self.fields = {}
+        self.include_extra_query_parameters = provider_def.get('include_extra_query_parameters', False)  # noqa
+        self._fields = {}
         self.filename = None
 
         # for coverage providers
@@ -82,11 +87,31 @@ class BaseProvider:
         """
         Get provider field information (names, types)
 
-        :returns: dict of fields
+        Example response:
+            {'field1': {'type': 'string'}, 'field2': {'type': 'number'}}
+
+        :returns: dict of field names and their associated JSON Schema types
         """
 
         raise NotImplementedError()
 
+    @property
+    def fields(self) -> dict:
+        """
+        Store provider field information (names, types)
+
+        Example response:
+            {'field1': {'type': 'string'}, 'field2': {'type': 'number'}}
+
+        :returns: dict of dicts (field names and their
+                  associated JSON Schema definitions)
+        """
+
+        if hasattr(self, '_fields'):
+            return self._fields
+        else:
+            return self.get_fields()
+
     def get_schema(self, schema_type: SchemaType = SchemaType.item):
         """
         Get provider schema model
@@ -122,6 +147,20 @@ class BaseProvider:
 
         raise NotImplementedError()
 
+    def get_domains(self, properties=[], current=False):
+        """
+        Get domains from dataset
+
+        :param properties: `list` of property names
+        :param current: `bool` of whether to provide list of live
+                        values (default `False`)
+
+        :returns: `tuple` of domains and whether they are based on the
+                  current/live dataset
+        """
+
+        raise NotImplementedError()
+
     def query(self):
         """
         query the provider
@@ -176,24 +215,6 @@ class BaseProvider:
 
         raise NotImplementedError()
 
-    def get_coverage_domainset(self):
-        """
-        Provide coverage domainset
-
-        :returns: CIS JSON object of domainset metadata
-        """
-
-        raise NotImplementedError()
-
-    def get_coverage_rangetype(self):
-        """
-        Provide coverage rangetype
-
-        :returns: CIS JSON object of rangetype metadata
-        """
-
-        raise NotImplementedError()
-
     def _load_and_prepare_item(self, item, identifier=None,
                                accept_missing_identifier=False,
                                raise_if_exists=True):
@@ -269,39 +290,46 @@ class BaseProvider:
         return f'<BaseProvider> {self.type}'
 
 
-class ProviderGenericError(Exception):
+class ProviderGenericError(GenericError):
     """provider generic error"""
-    pass
+    default_msg = 'generic error (check logs)'
 
 
 class ProviderConnectionError(ProviderGenericError):
     """provider connection error"""
-    pass
+    default_msg = 'connection error (check logs)'
 
 
 class ProviderTypeError(ProviderGenericError):
     """provider type error"""
-    pass
+    default_msg = 'invalid provider type'
+    http_status_code = HTTPStatus.BAD_REQUEST
 
 
 class ProviderInvalidQueryError(ProviderGenericError):
     """provider invalid query error"""
-    pass
+    ogc_exception_code = 'InvalidQuery'
+    http_status_code = HTTPStatus.BAD_REQUEST
+    default_msg = "query error"
 
 
 class ProviderQueryError(ProviderGenericError):
     """provider query error"""
-    pass
+    default_msg = 'query error (check logs)'
 
 
 class ProviderItemNotFoundError(ProviderGenericError):
     """provider item not found query error"""
-    pass
+    ogc_exception_code = 'NotFound'
+    http_status_code = HTTPStatus.NOT_FOUND
+    default_msg = 'identifier not found'
 
 
 class ProviderNoDataError(ProviderGenericError):
     """provider no data error"""
-    pass
+    ogc_exception_code = 'InvalidParameterValue'
+    http_status_code = HTTPStatus.NO_CONTENT
+    default_msg = 'No data found'
 
 
 class ProviderNotFoundError(ProviderGenericError):
@@ -321,4 +349,10 @@ class ProviderInvalidDataError(ProviderGenericError):
 
 class ProviderRequestEntityTooLargeError(ProviderGenericError):
     """provider request entity too large error"""
-    pass
+    http_status_code = HTTPStatus.REQUEST_ENTITY_TOO_LARGE
+
+    def __init__(self, msg=None, *args, user_msg=None) -> None:
+        if msg and not user_msg:
+            # This error type shows the error by default
+            user_msg = msg
+        super().__init__(msg, *args, user_msg=user_msg)
