@@ -3,7 +3,7 @@
 # Authors: Francesco Bartoli <xbartolone@gmail.com>
 # Authors: Tom Kralidis <tomkralidis@gmail.com>
 #
-# Copyright (c) 2020 Francesco Bartoli
+# Copyright (c) 2025 Francesco Bartoli
 # Copyright (c) 2023 Tom Kralidis
 #
 # Permission is hereby granted, free of charge, to any person
@@ -73,9 +73,9 @@ class BaseMVTProvider(BaseTileProvider):
     def get_tiling_schemes(self):
 
         tile_matrix_set_links_list = [
-                TileMatrixSetEnum.WORLDCRS84QUAD.value,
-                TileMatrixSetEnum.WEBMERCATORQUAD.value
-            ]
+            TileMatrixSetEnum.WORLDCRS84QUAD.value,
+            TileMatrixSetEnum.WEBMERCATORQUAD.value
+        ]
         tile_matrix_set_links = [
             item for item in tile_matrix_set_links_list
             if item.tileMatrixSet in self.options['schemes']]
@@ -95,7 +95,8 @@ class BaseMVTProvider(BaseTileProvider):
         :returns: `dict` of item tile service
         """
 
-        url = urlparse(self.data)
+        # self.data will be a dict when using MVTPostgresProvider
+        url = urlparse(self.data) if isinstance(self.data, str) else urlparse('/') # noqa
         baseurl = baseurl or f'{url.scheme}://{url.netloc}'
         # @TODO: support multiple types
         tile_type = tile_type or self.format_type
@@ -214,7 +215,7 @@ class BaseMVTProvider(BaseTileProvider):
                                              tileset, title, description,
                                              keywords, **kwargs)
         else:
-            raise NotImplementedError(f"_{metadata_format.upper()}_ is not supported") # noqa
+            raise NotImplementedError(f"_{metadata_format.upper()}_ is not supported")  # noqa
 
     def get_tms_links(self):
         """
