@@ -32,6 +32,8 @@ import csv
 import itertools
 import logging
 
+from shapely.geometry import box, Point
+
 from pygeoapi.provider.base import (BaseProvider, ProviderInvalidQueryError,
                                     ProviderItemNotFoundError,
                                     ProviderQueryError)
@@ -99,6 +101,7 @@ class CSVProvider(BaseProvider):
         :param limit: number of records to return (default 10)
         :param datetime_: temporal (datestamp or extent)
         :param resulttype: return results or hit limit (default results)
+        :param bbox: bounding box [minx,miny,maxx,maxy]
         :param properties: list of tuples (name, value)
         :param select_properties: list of property names
         :param skip_geometry: bool of whether to skip geometry (default False)
@@ -120,6 +123,7 @@ class CSVProvider(BaseProvider):
         with open(self.data) as ff:
             LOGGER.debug('Serializing DictReader')
             data_ = csv.DictReader(ff)
+
             if properties:
                 for prop in properties:
                     if prop[0] not in data_.fieldnames:
@@ -131,10 +135,17 @@ class CSVProvider(BaseProvider):
                     lambda p: all(
                         [p[prop[0]] == prop[1] for prop in properties]), data_)
 
+            if bbox:
+                LOGGER.debug('processing bbox parameter')
+                data_ = filter(
+                    lambda f: all(
+                        [self._intersects(f, bbox)]), data_)
+
             if resulttype == 'hits':
                 LOGGER.debug('Returning hits only')
                 feature_collection['numberMatched'] = len(list(data_))
                 return feature_collection
+
             LOGGER.debug('Slicing CSV rows')
             for row in itertools.islice(data_, 0, None):
                 try:
@@ -193,6 +204,24 @@ class CSVProvider(BaseProvider):
 
         return feature_collection
 
+    def _intersects(self, data, bbox):
+        """
+        Helper function to evaluate point geometry intersection with a bbox
+
+        :param geometry: `dict` of CSV row
+        :param bbox: `list` of bbox
+
+        :returns: `bool` of whether point geometry intersects with bbox
+        """
+
+        if None in [data.get(self.geometry_x), data.get(self.geometry_y)]:
+            return True
+
+        point = Point(data[self.geometry_x], data[self.geometry_y])
+        bbox2 = box(*bbox)
+
+        return bbox2.intersects(point)
+
     @crs_transform
     def query(self, offset=0, limit=10, resulttype='results',
               bbox=[], datetime_=None, properties=[], sortby=[],
@@ -215,7 +244,7 @@ class CSVProvider(BaseProvider):
         """
 
         return self._load(offset, limit, resulttype,
-                          properties=properties,
+                          bbox=bbox, properties=properties,
                           select_properties=select_properties,
                           skip_geometry=skip_geometry)
 
