@@ -38,6 +38,7 @@ from dataclasses import dataclass
 from datetime import date, datetime, time, timezone
 from decimal import Decimal
 from enum import Enum
+from heapq import heappush
 import json
 import logging
 import mimetypes
@@ -1054,3 +1055,58 @@ def _inplace_replace_geometry_filter_name(
             else:
                 _inplace_replace_geometry_filter_name(
                     sub_node, geometry_column_name)
+
+
+def get_from_headers(headers: dict, header_name: str) -> str:
+    """
+    Gets case insensitive value from dictionary.
+    This is particularly useful when trying to get
+    headers from Starlette and Flask without issue
+
+    :param headers: `dict` of request headers.
+    :param header_name: Name of request header.
+
+    :returns: `str` value of header
+    """
+
+    cleaned_headers = {k.strip().lower(): v for k, v in headers.items()}
+    return cleaned_headers.get(header_name.lower(), '')
+
+
+def get_choice_from_headers(headers: dict,
+                            header_name: str,
+                            all: bool = False) -> Union[str, List[str]]:
+    """
+    Gets choices from a request dictionary,
+    considering numerical ordering of preferences.
+    Supported are complex preference strings (e.g. "fr-CH, fr;q=0.9, en;q=0.8")
+
+    :param headers: `dict` of request headers.
+    :param header_name: Name of request header.
+    :param all: bool to return one or all header values.
+
+    :returns: Sorted choice or choices from header
+    """
+
+    # Select header of interest
+    header = get_from_headers(headers=headers, header_name=header_name)
+    if header == '':
+        return
+
+    # Parse choices, extracting optional q values (defaults to 1.0)
+    choices = []
+    for i, part in enumerate(header.split(',')):
+        match = re.match(r'^([^;]+)(?:;q=([\d.]+))?$', part.strip())
+        if match:
+            value, q_value = match.groups()
+            q_value = float(q_value) if q_value else 1.0
+
+            # Sort choices by q value and index
+            if 0 <= q_value <= 1:
+                heappush(choices, (1 / q_value, i, value))
+
+    # Drop q value
+    sorted_choices = [choice[-1] for choice in choices]
+
+    # Return one or all choices
+    return sorted_choices if all else sorted_choices[0]
